@@ -14,12 +14,20 @@ REQUEST_SIZE = 2 ** 14
 class Peer(object):
     # Can't initialize without a dictionary. Handshake
     # takes place using socket before peer init
-    def __init__(self, sock, reactor, torrent):
+    def __init__(self, sock, reactor, torrent, in_location):
         print 'inside peer.__init__'
         self.sock = sock
         self.sock.setblocking(True)
         self.reactor = reactor
         self.torrent = torrent
+
+        # What am I trying to do?
+        # I only want self.location to include keys and vals
+        # if val for key in in_location
+        loc_list = ['city', 'region_name', 'country_name']
+        self.location = {key: in_location[key] for key in loc_list
+                         if key in in_location and in_location[key]}
+
         self.valid_indices = []
         self.bitfield = None
         self.max_size = 16 * 1024
@@ -34,8 +42,9 @@ class Peer(object):
         self.ischoking = True
         self.isinterested = False
         self.unchoke()  # Testing to see if this makes a difference
-        activate_dict = {'kind': 'activate', 'address': self.getpeername()}
-        self.torrent.switchboard.try_vis_handoff(activate_dict)
+        activate_dict = {'kind': 'activate', 'address': self.getpeername(),
+                         'location': self.location}
+        self.torrent.switchboard.broadcast(activate_dict)
 
     def fileno(self):
         return self.sock.fileno()
@@ -226,7 +235,7 @@ class Peer(object):
                 # Take care of visualizer stuff
                 piece_dict = {'kind': 'piece', 'peer': self.sock.getpeername(),
                               'piece_index': piece_index}
-                self.torrent.switchboard.try_vis_handoff(piece_dict)
+                self.torrent.switchboard.broadcast(piece_dict)
 
                 print ('writing piece {}. Length is '
                        '{}').format(repr(piece_bytes)[:10] + '...',
@@ -234,6 +243,8 @@ class Peer(object):
 
                 # Write out
                 byte_index = piece_index * self.torrent.piece_length
+                self.piece = self.init_piece()
+                self.request_all()
                 self.torrent.switchboard.write(byte_index, piece_bytes)
                 self.torrent.switchboard.mark_off(piece_index)
                 print self.torrent.switchboard.bitfield
@@ -242,8 +253,8 @@ class Peer(object):
                     self.reactor.is_running = False
             else:
                 print "Bad data -- hash doesn't match. Discarding piece."
-            self.piece = self.init_piece()
-            self.request_all()
+                self.piece = self.init_piece()
+                self.request_all()
 
     def pcancel(self):
         print 'pcancel'
@@ -299,7 +310,7 @@ class Peer(object):
         request_dict = {'kind': 'request',
                         'peer': self.sock.getpeername(),
                         'piece': self.piece.index}
-        self.torrent.switchboard.try_vis_handoff(request_dict)
+        self.torrent.switchboard.broadcast(request_dict)
         print 'next request:', request_dict
 
     def get_last_block_size(self):
