@@ -161,7 +161,7 @@ def build_bitfield(heads_and_tails=[], num_pieces=0):
 
 class Switchboard(object):
     def __init__(self, dirname='', file_list=[], piece_length=0, num_pieces=0,
-                 multifile=False, download_all=False):
+                 multifile=False, download_all=False, vis_socket=None):
         self.dirname = dirname
         self.file_list = copy.deepcopy(file_list)
         self.piece_length = piece_length
@@ -170,6 +170,8 @@ class Switchboard(object):
                             else [0])
 
         self.download_all = download_all
+        self.vis_socket = vis_socket
+        self.encoder = json.JSONEncoder()
 
         if self.download_all:
             self.want_file_pos = range(len(self.file_list))
@@ -180,9 +182,9 @@ class Switchboard(object):
 
         self.outfiles = []
         self.queued_messages = []
-        self.vis_write_sock = None
         if self.dirname:
-            os.mkdir(self.dirname)
+            if not os.path.exists(self.dirname):
+                os.mkdir(self.dirname)
             os.chdir(os.path.join(os.getcwd(), self.dirname))
         want_files = [self.file_list[index] for index in self.want_file_pos]
         if multifile:
@@ -230,15 +232,10 @@ class Switchboard(object):
     def set_piece_index(self, piece_index):
         self.piece_index = piece_index
 
-    def set_sock(self, sock):
-        self.vis_write_sock = sock
-        self.switchboard.vis_write_sock = sock
-
     # TODO -- refactor write to simply map from a piece index to a set
     # of files and byte indices so I can implement seeding.
     # Write should contain a call to another method that returns
     # files and byte ranges
-
     def write(self, byte_index, block):
 
         # TODO -- is there a way to catch this exception earlier?
@@ -303,23 +300,22 @@ class Switchboard(object):
         init_dict['files'] = self.file_list
         init_dict['heads_and_tails'] = self.heads_and_tails
         init_dict['num_pieces'] = self.num_pieces
-        self.try_vis_handoff(init_dict)
+        self.broadcast(init_dict)
 
-    def try_vis_handoff(self, data_dict):
+    def broadcast(self, data_dict):
         '''
         Send to the visualizer (if there is one) or enqueue for later
         '''
-        try:
-            self.vis_write_sock.send(json.dumps(data_dict))
-        except:
+        if self.vis_socket:
             self.queued_messages.append(data_dict)
+            self.send_all_updates()
 
     def send_all_updates(self):
-        assert self.vis_write_sock
         while self.queued_messages:
             # TODO -- ask if this makes sense
-            next_message = json.dumps(self.queued_messages.pop(0)) + '\r\n\r\n'
-            self.vis_write_sock.send(next_message)
+            next_message = (self.encoder.encode(self.queued_messages.pop(0)) +
+                            '\r\n\r\n')
+            self.vis_socket.send(next_message)
 
     def mark_off(self, index):
         self.bitfield[index] = False
@@ -334,24 +330,3 @@ class Switchboard(object):
     def close(self):
         for i in self.outfiles:
             i.close()
-
-
-def file_starts_test():
-    from tparser import bdecode_file
-    myinfo = bdecode_file('/Users/jeffblagdon/Desktop/dorian.torrent')['info']
-    some_file_starts = get_file_starts(myinfo['files'])
-    piece_length = myinfo['piece length']
-    piece_index = 836
-    byte_index = piece_length * piece_index
-    rightmost = get_rightmost_index(byte_index=byte_index,
-                                    file_starts=some_file_starts)
-    file_internal_index = byte_index - some_file_starts[rightmost]
-    assert file_internal_index >= 0
-
-
-def all_subdirs_test():
-    print all_subdirs(os.getcwd())
-
-
-if __name__ == '__main__':
-    all_subdirs_test()
